@@ -1,4 +1,5 @@
 import unittest
+
 from ddt import ddt, data, file_data, unpack
 from test.mycode import larger_than_two, has_three_elements, is_a_greeting
 
@@ -8,7 +9,6 @@ except ImportError:  # pragma: no cover
     have_yaml_support = False
 else:
     have_yaml_support = True
-    del yaml
 
 # A good-looking decorator
 needs_yaml = unittest.skipUnless(
@@ -20,6 +20,19 @@ class Mylist(list):
     pass
 
 
+class MyClass:
+    def __init__(self, **kwargs):
+        for field, value in kwargs.items():
+            setattr(self, field, value)
+
+    def __eq__(self, other):
+        return isinstance(other, dict) and vars(self) == other or \
+               isinstance(other, MyClass) and vars(self) == vars(other)
+
+    def __str__(self):
+        return "TestObject %s" % vars(self)
+
+
 def annotated(a, b):
     r = Mylist([a, b])
     setattr(r, "__name__", "test_%d_greater_than_%d" % (a, b))
@@ -59,34 +72,34 @@ class FooTestCase(unittest.TestCase):
         self.assertIsNotNone(getattr(value, "__name__"))
         self.assertIsNotNone(getattr(value, "__doc__"))
 
-    @file_data("test_data_dict_dict.json")
+    @file_data('data/test_data_dict_dict.json')
     def test_file_data_json_dict_dict(self, start, end, value):
         self.assertLess(start, end)
         self.assertLess(value, end)
         self.assertGreater(value, start)
 
-    @file_data('test_data_dict.json')
+    @file_data('data/test_data_dict.json')
     def test_file_data_json_dict(self, value):
         self.assertTrue(has_three_elements(value))
 
-    @file_data('test_data_list.json')
+    @file_data('data/test_data_list.json')
     def test_file_data_json_list(self, value):
         self.assertTrue(is_a_greeting(value))
 
     @needs_yaml
-    @file_data("test_data_dict_dict.yaml")
+    @file_data('data/test_data_dict_dict.yaml')
     def test_file_data_yaml_dict_dict(self, start, end, value):
         self.assertLess(start, end)
         self.assertLess(value, end)
         self.assertGreater(value, start)
 
     @needs_yaml
-    @file_data('test_data_dict.yaml')
+    @file_data('data/test_data_dict.yaml')
     def test_file_data_yaml_dict(self, value):
         self.assertTrue(has_three_elements(value))
 
     @needs_yaml
-    @file_data('test_data_list.yaml')
+    @file_data('data/test_data_list.yaml')
     def test_file_data_yaml_list(self, value):
         self.assertTrue(is_a_greeting(value))
 
@@ -130,3 +143,15 @@ class FooTestCase(unittest.TestCase):
     def test_list_extracted_with_doc(self, first_value, second_value):
         """Extract into args with first value {} and second value {}"""
         self.assertTrue(first_value > second_value)
+
+
+if have_yaml_support:
+    # This test will only succeed if the execution context is from the ddt
+    # directory. pyyaml cannot locate test.test_example.MyClass otherwise!
+
+    @ddt
+    class YamlOnlyTestCase(unittest.TestCase):
+        @file_data('data/test_custom_yaml_loader.yaml', yaml.FullLoader)
+        def test_custom_yaml_loader(self, instance, expected):
+            """Test with yaml tags to create specific classes to compare"""
+            self.assertEqual(expected, instance)
